/*
  ‘Time Blink BIS’
 THIS SKETCH IS BASED ON 
 David A. Mellis’ (2005) ‘BLINK without Delay’ sketch
 AND MODIFIED BY Paul Stoffregen (2010)
 http://www.arduino.cc/en/Tutorial/BlinkWithoutDelay
 
 Blink a RED and a GREEN LED without using the delay function.
 The blink period is defined on 1/6 of a second,
 around 167milliSeconds
 
 curcuit with a bicolor LED light:
 left LED short leg     (+) --> 220Ohms Resistor --> pin 13
 right LED short leg    (+) --> 220Ohms Resistor --> pin 12
 middle LED long led    (-) --> GND
 
 Modified by Angelos Floros, November 2013
 
 This example code is in the public domain.
 */

// declare any variable
const int ledPinL = 13; // left leg led Pin number
const int ledPinR = 12; // right leg led Pin number

// Blink Period in milliseconds
const float BlinkPeriod= 1000/3; 

// ledState used to set the LED
boolean ledState = LOW;   

// will store last time LED was updated
long previousMillis = 0; 
int CountBlink=0;


void setup() {                
  // initialize the digital pins 12 and 13 as outputs.
  pinMode(ledPinL, OUTPUT);   
  pinMode(ledPinR, OUTPUT);   
}

void loop() {

  // check to see if it’s time to blink the LED;
  // when the Current time minus the Previous time
  // bigger than the BlinkPeriod, then
  // a) store the new Current time as e Previous time
  // and b) switch the ledState mode
  // The Previous Time is stored in previousMillis var

  // start the timer and add it to currentMillis var
  unsigned long currentMillis = millis();

  if(currentMillis - previousMillis > BlinkPeriod) {

    // save the last time you blinked the LED 
    previousMillis = currentMillis;  

    // increase by 1 the CounterBlink var in every frame
    CountBlink++; 

    // Switch the LED mode
    switch (CountBlink % 4) {
    case 0:
      // Switch off both LED lights
      digitalWrite(ledPinL, LOW);        
      digitalWrite(ledPinR, LOW);
      break;  

    case 1:
      ledState=!ledState;
      // Apply the ledState Mode to left leg LED
      digitalWrite(ledPinL, ledState);
      // Apply the opposite of the ledState Mode to right leg LED         
      digitalWrite(ledPinR, !ledState);     
      break;

    case 2:
      // Switch off both LED lights
      digitalWrite(ledPinL, LOW);      
      digitalWrite(ledPinR, LOW);
      break; 

    case 3:
      ledState=!ledState;
      // Apply the ledState Mode to left leg LED
      digitalWrite(ledPinL, ledState);
      // Apply the opposite of the ledState Mode to right leg LED        
      digitalWrite(ledPinR, !ledState);     
      break;
    }    
  }
}

