/*
  State change detection (edge detection)
 	
 Often, you don't need to know the state of a digital input all the time,
 but you just need to know when the input changes from one state to another.
 For example, you want to know when a button goes from OFF to ON.  This is called
 state change detection, or edge detection.
 
 This example shows how to detect when a button or button changes from off to on
 and on to off.
 	
 The circuit:
 * pushbutton attached to pin 2 from +5V
 * 10K resistor attached to pin 2 from ground
 * LED attached from pin 13 to ground (or use the built-in LED on
 most Arduino boards)
 
 created  27 Sep 2005
 modified 30 Aug 2011
 by Tom Igoe
 
 This example code is in the public domain.
 	
 http://arduino.cc/en/Tutorial/ButtonStateChange
 
 */

// set pin numbers:
const int buttonPin = 2;     // the number of the RED pushbutton pin
const int ledPinR =  13;      // the number of the RED light of RGB LED pin
const int ledPinG =  12;      // the number of the GREEN light of RGB LED pin
const int ledPinB =  11;      // the number of the BLUE light of RGB LED pin

// Variables will change:
int buttonPushCounter = 0;   // counter for the number of button presses
int buttonState = 0;         // current state of the button
int lastButtonState = 0;     // previous state of the button

void setup() {
  // initialize the button pin as a input:
  pinMode(buttonPin, INPUT);
  // initialize the LED pin as an output:
  pinMode(ledPinR, OUTPUT);      
  pinMode(ledPinG, OUTPUT);      
  pinMode(ledPinB, OUTPUT);      
}


void loop() {
  // read the pushbutton input pin:
  buttonState = digitalRead(buttonPin);

  // compare the buttonState to its previous state
  if (buttonState != lastButtonState) {
    // if the state has changed, 
    // and when the button is released
    if (buttonState == LOW) {
      // increase the counter by one
      buttonPushCounter++;
    } 
  }
  // save the current state as the last state, 
  //for next time through the loop
  lastButtonState = buttonState;


  switch (buttonPushCounter % 4) {
  case 0: // Switch off all lights
    switchOffLEDs();
    break;  

  case 1: // Switch on Red light
    switchOffLEDs();
    digitalWrite(ledPinR, HIGH); 
    break;

  case 2: // Switch on Green light
    switchOffLEDs();
    digitalWrite(ledPinG, HIGH); 
    break; 

  case 3: // Switch on Blue light
    switchOffLEDs();
    digitalWrite(ledPinB, HIGH);     
    break;
  }    
}

void switchOffLEDs() {
  digitalWrite(ledPinR, LOW);
  digitalWrite(ledPinG, LOW);
  digitalWrite(ledPinB, LOW);
}

