/*
 ‘Disc Fade’ 
 based on ‘Knock Sensor’
 	
 This project uses a piezo disk to fade in and out 
 an led light.
 	
 The circuit:
 * piezo disk attached to pin A0
 * 1 Mohm resistor bridges the low and the high 
 voltage of the piezo disk
 * LED attached from pin 9 to ground
 * 220 ohm resistor attached to pin 9 from ground 
 
 (cleft) 2005 D. Cuartielles for K3
 edited by Scott Fitzgerald 14 April 2013 
 re-modified by Angelos Floros, August 2013	
 http://arduino.cc/en/Tutorial/KnockSensor
 */

// this constant won’t change:
const int ledPinR =  9;      // RED light pin
const int buttonPin = A0;    // pushbutton pin

int buttonPushCounter = 0;   // counts the button hits
int buttonState = 0;     // current state of the button
int lastButtonState = 0; // previous state of the button

int brightness = 0;      // how bright the LED is

// threshold value to decide when the detected sound is a knock or not
const int threshold = 100;  

// variable to store the value read from the sensor pin
int sensorReading = 0;  

// debouncePeriod is a time to ignore vibration values 
static int debounce=0;
static int debouncePeriod=50;

void setup() {
  // initialize the LED pins as an output:
  pinMode(ledPinR, OUTPUT);      
  // initialize serial communication:
  Serial.begin(9600);
}


void loop() {

  // read the sensor and store it in sensorReading:
  sensorReading = analogRead(buttonPin);  

  if(debounce==0){
    if(sensorReading>threshold){
      buttonPushCounter++;
      debounce=debouncePeriod;
    }
  }
  else { 
    debounce--;  
  }

  // save the current state as the last state
  lastButtonState = buttonState;

  switch (buttonPushCounter % 2) {
  case 0: // fade out the led 
    brightness = brightness--;
    break;

  case 1: // fade in the led 
    brightness = brightness++;
    break;
  }

  if (brightness>=255) { 
    brightness=255; 
  } 
  if (brightness<=0) {
    brightness=0; 
  }

  analogWrite(ledPinR, brightness);
  delay(10);

  //  Activate the Serial messages to track debounce
  //    Serial.print(sensorReading);
  //    Serial.print(", ");
  //    Serial.println(debounce);
}


