/*
  ‘Melody Keyboard’

 created August 2013 by Angelos Floros

 curcuit
 2 tact switches  (wire 1) --> +5V
 2 tact switches  (wire 2) --> 10KOhms Resistor --> GND
                           --> pins 12 and 11
 speaker   (high voltage)  --> pin 10
 speaker         (ground)  --> GND
 7 10K resistors  (leg 1)  --> pin 9
 7 10K resistors  (leg 2)  --> pins 2 to 8
                           --> 1 wire for each resistor

 This example code is part of the public domain
 */

// import the library (must be located in the
// Arduino/libraries directory)
#include <CapacitiveSensor.h>

// pin 9 sends electrical energy
// pins 2 to 8 sense a change
CapacitiveSensor cs_A = CapacitiveSensor(9, 8);
CapacitiveSensor cs_B = CapacitiveSensor(9, 7);
CapacitiveSensor cs_C = CapacitiveSensor(9, 6);
CapacitiveSensor cs_D = CapacitiveSensor(9, 5);
CapacitiveSensor cs_E = CapacitiveSensor(9, 4);
CapacitiveSensor cs_F = CapacitiveSensor(9, 3);
CapacitiveSensor cs_G = CapacitiveSensor(9, 2);

// notes are   [C4,  D4 , E4,  F4,  G4,  A4,  B4]
int melody[] = {262, 294, 330, 349, 392, 440, 494};
int noteDuration = 1000 / 4; // note duration

int threshold = 50; // threshold for turning the lamp on

// define pins
int speakerPin = 10;
const int ledPin = 13;  // led Attached to Arduino board
const int  buttonPinPlus = 2;  // button to increase
const int  buttonPinMinus = 3; // button to dicrease

int octave = 10;  // Button Hits counter
int lastbuttonStatePlus = 0; // previous state of the button Plus
int lastbuttonStateMinus = 0; // previous state of the button Minus
int buttonStateMinus = 0; // current state of the buttons
int buttonStatePlus = 0;

// debouncePeriod is the time that help us to ignore vibration values
static int debounce = 0;
static int debouncePeriod = 50; // find the proper value

void setup() {
  // open a serial connection
  Serial.begin(9600);
  // set the LED pin as an output
  pinMode(ledPin, OUTPUT);
  // initialize the button pins as inputs:
  pinMode(buttonPinPlus, INPUT);
  pinMode(buttonPinMinus, INPUT);

}

void loop() {

  // store the value reported by the sensor in a variable
  long noteA = cs_B.capacitiveSensor(30);
  long noteB = cs_A.capacitiveSensor(30);
  long noteC = cs_G.capacitiveSensor(30);
  long noteD = cs_F.capacitiveSensor(30);
  long noteE = cs_E.capacitiveSensor(30);
  long noteF = cs_D.capacitiveSensor(30);
  long noteG = cs_C.capacitiveSensor(30);

  int notes[] = {noteC, noteD, noteE, noteF, noteG, noteA, noteB};
Serial.print(noteA);
Serial.print("\t");
Serial.print(noteB);
Serial.print("\t");
Serial.print(noteC);
Serial.print("\t");
Serial.print(noteD);
Serial.print("\t");
Serial.print(noteE);
Serial.print("\t");
Serial.print(noteF);
Serial.print("\t");
Serial.println(noteG);


  // if the value is greater than the threshold
  for (int i = 0; i < 8; i++) {
    
      if (notes[i] > threshold) {
        if (debounce == 0) {
      debounce = debouncePeriod;
        tone(speakerPin, octave * melody[i], noteDuration);
        digitalWrite(ledPin, HIGH);
      }
    } else {
      debounce--;
    }
   // Serial.println(debounce);
  }
  // read the pushbuttons
  buttonStatePlus = digitalRead(buttonPinPlus);
  buttonStateMinus = digitalRead(buttonPinMinus);

  // compare the buttonStatePlus to its previous state
  if (buttonStatePlus != lastbuttonStatePlus) {
    // if the state has changed, increment the counter
    if (buttonStatePlus == HIGH) octave++;
  }

  // compare the buttonStatePlus to its previous state
  if (buttonStateMinus != lastbuttonStateMinus) {
    // if the state has changed, increment the counter
    if (buttonStateMinus == HIGH) octave--;
  }

  // save the current states as the last state
  lastbuttonStatePlus = buttonStatePlus;
  lastbuttonStateMinus = buttonStateMinus;

  digitalWrite(ledPin, LOW);
  noTone(speakerPin);
  delay(10);
}



