/*
 ‘SerialRead’  
 	
 Use Serial Communication to send messages to Arduino
 The push button reads the RGB pin modes
 
 circuit with a common Cathode RGB LED light
 2nd LED short led   (-) --> GND
 RED light 1st leg   (+) --> 220Ohms Resistor --> pin 11   
 GREEN light 3rd leg (+) --> 220Ohms Resistor --> pin 12
 BLUE light 4th leg  (+) --> 220Ohms Resistor --> pin 13  
 tact switch    (wire 1) --> +5V
 tact switch    (wire 2) --> 10KOhms Resistor --> GND 
                                              --> pin 2 
 created Aug 2013 by Angelos Floros
 
 This example code is in the public domain.	
 */

// set the RGB led and button pin numbers:
const int buttonPin = 2; // pushbutton pin
const int ledPinR =  13; // RED light of RGB LED pin
const int ledPinG =  12; // GREEN light of RGB LED pin
const int ledPinB =  11; // BLUE light of RGB LED pin

int buttonState = 0;  // current state of the button
int lastButtonState = 0; // previous state of the button

// create a function with arguments to control the RBG lights
void powerRGB(boolean modeR, boolean modeG, boolean modeB) {
  digitalWrite(ledPinR, modeR);
  digitalWrite(ledPinG, modeG);
  digitalWrite(ledPinB, modeB);
}

void setup() {

  // initialize the button pin as a input:
  pinMode(buttonPin, INPUT);
  // initialize the led pins as outputs:
  pinMode(ledPinR, OUTPUT);   
  pinMode(ledPinG, OUTPUT);   
  pinMode(ledPinB, OUTPUT);   

  // initialize serial communication:
  Serial.begin(9600);
}


void loop() {

  // read the pushbutton input pin:
  buttonState = digitalRead(buttonPin);
  if (buttonState != lastButtonState && buttonState==LOW) {
    Serial.print(digitalRead(ledPinR));
    Serial.print("\t");
    Serial.print(digitalRead(ledPinG));
    Serial.print("\t");
    Serial.println(digitalRead(ledPinB));
  }

  lastButtonState = buttonState;

  String mag=""; // Stores the Serial value

  if (Serial.available()>0)
  {
    while(Serial.available()>0) {
      mag+= char(Serial.read());
      delay(20);
    }
    Serial.println(mag);

    // RED is ON
    if(mag=="RED ON" || mag=="red on") {   
      digitalWrite(ledPinR, HIGH);    
    }   // RED is OFF
    else if(mag=="RED OFF" || mag=="red off") {   
      digitalWrite(ledPinR, LOW);    
    }  // GREEN is ON
    else if(mag=="GREEN ON" || mag=="green on") {    
      digitalWrite(ledPinG, HIGH);    
    }  // GREEN is OFF 
    else if(mag=="GREEN OFF" || mag=="green off") {  
      digitalWrite(ledPinG, LOW);    
    }  //  BLUE is ON
    else if(mag=="BLUE ON" || mag=="blue on") {    
      digitalWrite(ledPinB, HIGH);    
    }  // BLUE is OFF 
    else if(mag=="BLUE OFF" || mag=="blue off") {  
      digitalWrite(ledPinB, LOW);    
    }  // ALL is ON
    else if(mag=="ALL ON" || mag=="all on") {  
      powerRGB(HIGH, HIGH, HIGH);
    }  // ALL is OFF 
    else if(mag=="ALL OFF" || mag=="all off") {  
      powerRGB(LOW, LOW, LOW);   
    } // the typen message is not included
    else {
      Serial.println("No valid operation");
    }
  }
}



