/*
 ‘SerialWrite’  
 Based on Arduino sketch ‘State change detection’ 
 	
 Control an RGB led using a tact switch
 
 circuit with a common Cathode RGB LED light
 2nd LED short led   (-) --> GND
 RED light 1st leg   (+) --> 220Ohms Resistor --> pin 11   
 GREEN light 3rd leg (+) --> 220Ohms Resistor --> pin 12
 BLUE light 4th leg  (+) --> 220Ohms Resistor --> pin 13  
 tact switch    (wire 1) --> +5V
 tact switch    (wire 2) --> 10KOhms Resistor --> GND 
                         --> pin 2 
 
 created  27 Sep 2005
 modified 30 Aug 2011 by Tom Igoe
 re-modified Aug 2013 by Angelos Floros
 
 This example code is in the public domain.
 	
 http://arduino.cc/en/Tutorial/ButtonStateChange
 */

// set pin numbers:
const int buttonPin = 2; // pushbutton pin
const int ledPinR =  13; // RED light of RGB LED pin
const int ledPinG =  12; // GREEN light of RGB LED pin
const int ledPinB =  11; // BLUE light of RGB LED pin

// counter for the number of button presses
int buttonPushCounter = 0; 
int buttonState = 0;  // current state of the button
int lastButtonState = 0; // previous state of the button

// create a function to switch off all the lights
// this function can be called inside the loop()
void powerRGB(boolean modeR, boolean modeG, boolean modeB) {
  digitalWrite(ledPinR, modeR);
  digitalWrite(ledPinG, modeG);
  digitalWrite(ledPinB, modeB);
}

void setup() {
  // initialize the button pin as a input:
  pinMode(buttonPin, INPUT);
  // initialize the LED pin as an output:
  pinMode(ledPinR, OUTPUT);      
  pinMode(ledPinG, OUTPUT);      
  pinMode(ledPinB, OUTPUT); 
  Serial.begin(9600);  
  Serial.println("Begin SerialRGB");
}

void loop() {
  // read the pushbutton input pin:
  buttonState = digitalRead(buttonPin);

  // compare the buttonState to its previous state
  if (buttonState != lastButtonState) {
    // if the state has changed, 
    // and when the button is released (LOW mode)
    if (buttonState == LOW) {
      // increase the counter by one
      buttonPushCounter++;
      Serial.print("Buttons Hits ");
      Serial.print(buttonPushCounter % 5);
      Serial.print(": Power mode of Red, Green, Blue pins: "); 
      switch (buttonPushCounter % 5) {

      case 0: // Switch off all lights
        powerRGB(LOW, LOW, LOW);
        Serial.println("LOW, LOW, LOW, All lights are off");
        break;  

      case 1: // Switch on Red light
        powerRGB(HIGH, LOW, LOW);
        Serial.println("HIGH, LOW, LOW, Red light is on");
        break;

      case 2: // Switch on Green light
        powerRGB(LOW, HIGH, LOW);
        Serial.println("LOW, HIGH, LOW, Green light is on");
        break; 

      case 3: // Switch on Blue light
        powerRGB(LOW, LOW, HIGH); 
        Serial.println("LOW, LOW, HIGH, Blue light is on");
        break;

      case 4: // Switch on all lights
        powerRGB(HIGH, HIGH, HIGH);
        Serial.println("HIGH, HIGH, HIGH, All lights are on");
        break; 
      }    
    } 
  }
  // save  the current state as the last state, 
  //for next time through the loop
  lastButtonState = buttonState;
  delay(10);
}


