/*
  State change detection (edge detection)
 	
 This project uses a button to fade in and out a light.
 	
 The circuit:
 * pushbutton attached to pin 2 from +5V
 * 10 Kohm resistor attached to pin 2 from ground
 * LED attached from pin 9 to ground
 * 220 ohm resistor attached to pin 9 from ground 
 
 created  27 Sep 2005
 modified 30 Aug 2011  by Tom Igoe
 modified Aug 2013 by Angelos Floros
 This example code is in the public domain.
 	
 http://arduino.cc/en/Tutorial/ButtonStateChange
 
 */

// this constant won’t change:
const int ledPinR =  9;      // RED light pin
const int buttonPin = 2;     // pushbutton pin

int buttonCounter = 0;   // counter for the number of button presses
int buttonState = 0;     // current state of the button
int lastButtonState = 0; // previous state of the button

int brightness = 0;      // how bright the LED is

void setup() {
  // initialize the button pin as a input:
  pinMode(buttonPin, INPUT);
  // initialize the LED pins as an output:
  pinMode(ledPinR, OUTPUT);      
  // initialize serial communication:
  Serial.begin(9600);
}


void loop() {
  // read the pushbutton input pin:
  buttonState = digitalRead(buttonPin);

  // compare the buttonState to its previous state
  if (buttonState != lastButtonState) {
    buttonCounter++;
  } 

  // save the current state as the last state
  lastButtonState = buttonState;

  switch (buttonCounter % 2) {
  case 0: // fade out the led 
    brightness = brightness--;
    break;

  case 1: // fade in the led 
    brightness = brightness++;
    break;
  }


  if (brightness>=255) { 
    Serial.println("Led is on");
    brightness=255; 
  } 
  if (brightness<=0) {
    Serial.println("LED is off");
    brightness=0; 
  }

  analogWrite(ledPinR, brightness);
  delay(5);
}





