/*
  ‘Time Blink BIS’
 THIS SKETCH IS BASED ON 
 David A. Mellis’ (2005) ‘BLINK without Delay’ sketch
 AND MODIFIED BY Paul Stoffregen (2010)
 http://www.arduino.cc/en/Tutorial/BlinkWithoutDelay
 
 Switches the blink effect, 
 between a Red and a Green LED light, 
 using the timer. 
 The blink period is defined on 1/6 of a second,
 around 167 milliseconds
 
 curcuit 
 RED LED short led   (-) --> GND
 RED LED long leg    (+) --> 220Ohms Resistor --> pin 13
 GREEN LED short led (-) --> GND
 GREEN LED long leg  (+) --> 220Ohms Resistor --> pin 12 
 
 Modified by Angelos Floros, November 2013
 
 This example code is in the public domain.
 */

// declare any variable
const int ledPinR = 13; // RED led Pin number
const int ledPinG = 12; // GREEN led Pin number

// Blink Period in milliseconds
const float BlinkPeriod= 1000/6; 

// ledState used to set the LED
boolean ledState = LOW;   

// will store last time LED was updated
long previousMillis = 0; 



void setup() {                
  // initialize the digital pins 12 and 13 as outputs.
  pinMode(ledPinR, OUTPUT);   
  pinMode(ledPinG, OUTPUT);   
}


void loop() {
  
  // start the timer and add it to currentMillis var
  unsigned long currentMillis = millis();

  // check to see if it’s time to blink the LED;
  // when the Current time minus the Previous time
  // bigger than the BlinkPeriod, then
  // a) store the new Current time as e Previous time
  // and b) switch the ledState mode
  // The Previous Time is stored in previousMillis var

  if(currentMillis - previousMillis > BlinkPeriod) {
  
    // save the Current time as a Previous time 
    previousMillis = currentMillis;  

    // Switch the LED mode
    ledState = !ledState;

    // Apply the ledState Mode to RED LED
    digitalWrite(ledPinR, ledState);
    // Apply the opposite of the ledState Mode to GREEN LED          
    digitalWrite(ledPinG, !ledState);     
  }
}


