/*
  ‘Button Melody’
 based on arduino example ‘Play Melody’

 Play a melody in different octaves using 2 buttons
 Based on Arduino example ‘Tone Melody’
 created 21 Jan 2010 and  
 modified 30 Aug 2011 by Tom Igoe 
 http://arduino.cc/en/Tutorial/Tone

 circuit:
 * 8-ohm speaker on digital pin 8
 
  re-modified by Angelos Floros
 This example code is in the public domain.
  
 */

int speakerPin =8;

// notes in the melody:
// notes are   [C4,  G3 , G3,  A3,  G3,  0, B3,  C4]
int melody[] = {262, 196, 196, 220, 196, 0, 247, 262};

// note durations: 4 = quarter note, 8 = eighth note, etc.:
int noteDurations[] = {4, 8, 8, 4, 4, 4, 4, 4 };

const int  buttonPinPlus = 2;  // button to increase
const int  buttonPinMinus = 3; // button to dicrease

// Button Hits counter
int buttonPushCounter = 10;  

// previous state of the buttons
int lastbuttonStatePlus = 0; 
int lastbuttonStateMinus = 0;     

// current state of the buttons
int buttonStateMinus = 0;         
int buttonStatePlus = 0;

void setup() {
 
  // initialize the button pins as a input:
  pinMode(buttonPinPlus, INPUT);
  pinMode(buttonPinMinus, INPUT);

}

void loop() {

  // iterate over the notes of the melody:
  for (int thisNote = 0; thisNote < 8; thisNote++) {
    // read the pushbuttons
    buttonStatePlus = digitalRead(buttonPinPlus);
    buttonStateMinus = digitalRead(buttonPinMinus);

    // compare the buttonStatePlus to its previous state
    if (buttonStatePlus != lastbuttonStatePlus) {
      // if the state has changed, increment the counter
      if (buttonStatePlus == HIGH) {
        // if the current state is HIGH then the button
        // wend from off to on:
        buttonPushCounter++;
      }  
    }

    // save the current state as the last state
    lastbuttonStatePlus = buttonStatePlus;

    // compare the buttonStatePlus to its previous state
    if (buttonStateMinus != lastbuttonStateMinus) {
      // if the state has changed, increment the counter
      if (buttonStateMinus == HIGH) {
        // if the current state is HIGH then the button
        // wend from off to on:
        buttonPushCounter--;
      } 
    }

    // save the current state as the last state
    lastbuttonStateMinus = buttonStateMinus;

    // to calculate the note duration, take one second 
    // divided by the note type.
    //e.g. quarter note = 1000/4, eighth note = 1000/8, etc.
    int noteDuration = 1000/noteDurations[thisNote];
    tone(speakerPin, 
buttonPushCounter*melody[thisNote],noteDuration);

    // to distinguish the notes, 
    // set a minimum time between them.
    // the note’s duration + 30% seems to work well:
    int pauseBetweenNotes = noteDuration * 1.30;
    delay(pauseBetweenNotes);
    // stop the tone playing:
    noTone(speakerPin);
  }
  delay(300);
}
